==> jffnms_0.7.8.orig.tar.gz: jffnms-0.7.8/lib/api.user.inc.php <==
<?
    function user_add ($username,$default_profile = 1){ 
	if ($username) {
    	    $query="Insert into auth (usern) VALUES ('$username')";
    	    //echo "$query\n";
    	    $result = db_query ($query) or die ("Query failed - USERADD-1 - ".db_error());
    	    $user_id = db_insert_id();

    	    if ($default_profile==1) {
		$query = "select id,default_value from profiles_options where use_default = 1"; //FIXME order
    		$result = db_query($query) or die ("Query Filed - USERADD-2 - ".db_error()); 

		while ($row = db_fetch_array($result)) { //add every default option to the user profile
		    profile_add_option($user_id,$row["id"]);
		    //profile_modify_value($user_id,$row["id"],$row["default_value"]);
		}
	    }
	}		
	return $user_id;
    }

    function user_get_id($username){
	if ($username) {
	    $query = "select id from auth where usern = '$username'";
	    $result = db_query($query) or die ("Query Failed - USER_GET_ID-1 - ".db_error());
	
	    if (db_num_rows($result)==1) {
		$row = db_fetch_array($result);
    		return $row["id"];
	    }
	}
	return false;
    }

    function user_get_username($user_id){
	if ($user_id > 0) {
	    $query = "select usern from auth where id = '$user_id'";
	    $result = db_query($query) or die ("Query Failed - USER_GET_USERNAME-1 - ".db_error());
	    $row = db_fetch_array($result);
	}
	return $row["usern"];
    }

    function user_del ($user_id){ 
	if ($user_id) {
	    foreach (profiles_list($user_id) as $option)  
		profile_del_option($user_id,$option[profile_option]); //delete all user profile options

	    foreach (triggers_users_list(NULL,$user_id) as $user) //delete all user triggers
	        triggers_users_del($user[id]);

	    if ((count(profiles_list($user_id)) == 0) && 
		(count(triggers_users_list(NULL,$user_id)) == 0) )
		return db_delete("auth",$user_id); //if everthing is ok delete the user
	    else 
		return FALSE;
	}	
    }

    function user_modify($user_id, $usern, $old_password, $new_password, $fullname, $router) {

	if ($new_password == $old_password) $passwd = $new_password;
	    else if (!empty($new_password)) $passwd = crypt($new_password);
		
	if (empty($router)) unset($router);
	if (empty($usern)) unset($usern);
	if (empty($passwd)) unset($passwd);
	
    	$user_fields = compact("fullname","usern","passwd","router");
		
	return db_update("auth",$user_id,$user_fields);
    }

    function users_list ($ids = NULL,$where_special = NULL) { 
        return get_db_list("auth",$ids, "*", //table,ids,fields	
		array_merge(
		    array(array("id",">",1)),
		    $where_special), //where
		array(array("id","desc")) ); //order 
    }

?>

==> jffnms_0.7.9.orig.tar.gz: jffnms-0.7.9/lib/api.user.inc.php <==
<?
    function user_add ($username,$default_profile = 1){ 
	if ($username) {
    	    $query="Insert into auth (usern) VALUES ('$username')";
    	    //echo "$query\n";
    	    $result = db_query ($query) or die ("Query failed - USERADD-1 - ".db_error());
    	    $user_id = db_insert_id();

    	    if ($default_profile==1) {
		$query = "select id,default_value from profiles_options where use_default = 1"; //FIXME order
    		$result = db_query($query) or die ("Query Filed - USERADD-2 - ".db_error()); 

		while ($row = db_fetch_array($result)) { //add every default option to the user profile
		    profile_add_option($user_id,$row["id"]);
		    //profile_modify_value($user_id,$row["id"],$row["default_value"]);
		}
	    }
	}		
	return $user_id;
    }

    function user_get_id($username){
	if ($username) {
	    $query = "select id from auth where usern = '$username'";
	    $result = db_query($query) or die ("Query Failed - USER_GET_ID-1 - ".db_error());
	
	    if (db_num_rows($result)==1) {
		$row = db_fetch_array($result);
    		return $row["id"];
	    }
	}
	return false;
    }

    function user_get_username($user_id){
	if ($user_id > 0) {
	    $query = "select usern from auth where id = '$user_id'";
	    $result = db_query($query) or die ("Query Failed - USER_GET_USERNAME-1 - ".db_error());
	    $row = db_fetch_array($result);
	}
	return $row["usern"];
    }

    function user_del ($user_id){ 
	if ($user_id) {
	    foreach (profiles_list($user_id) as $option)  
		profile_del_option($user_id,$option[profile_option]); //delete all user profile options

	    foreach (triggers_users_list(NULL,$user_id) as $user) //delete all user triggers
	        triggers_users_del($user[id]);

	    if ((count(profiles_list($user_id)) == 0) && 
		(count(triggers_users_list(NULL,$user_id)) == 0) )
		return db_delete("auth",$user_id); //if everthing is ok delete the user
	    else 
		return FALSE;
	}	
    }

    function user_modify($user_id, $usern, $old_password, $new_password, $fullname, $router) {

	if ($new_password == $old_password) $passwd = $new_password;
	    else if (!empty($new_password)) $passwd = crypt($new_password);
		
	if (empty($router)) unset($router);
	if (empty($usern)) unset($usern);
	if (empty($passwd)) unset($passwd);
	
    	$user_fields = compact("fullname","usern","passwd","router");
		
	return db_update("auth",$user_id,$user_fields);
    }

    function users_list ($ids = NULL,$where_special = NULL) { 
	
	if (!is_array($where_special)) $where_special = array();

        return get_db_list("auth",$ids, "*", //table,ids,fields	
		array_merge(
		    array(array("id",">",1)),
		    $where_special), //where
		array(array("usern","asc")) ); //order 
    }

?>
